"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkflowTheiaFrontendModule = void 0;
/********************************************************************************
 * Copyright (c) 2019-2022 EclipseSource and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
const theia_integration_1 = require("@eclipse-glsp/theia-integration");
const core_1 = require("@theia/core");
const browser_1 = require("@theia/core/lib/browser");
const sprotty_theia_1 = require("sprotty-theia");
const workflow_language_1 = require("../common/workflow-language");
const workflow_diagram_configuration_1 = require("./diagram/workflow-diagram-configuration");
const workflow_diagram_readonly_view_1 = require("./diagram/workflow-diagram-readonly-view");
const workflow_keybinding_contribution_1 = require("./diagram/workflow-keybinding-contribution");
const workflow_navigation_context_menu_1 = require("./diagram/workflow-navigation-context-menu");
const workflow_task_editing_context_menu_1 = require("./diagram/workflow-task-editing-context-menu");
const external_navigation_example_1 = require("./external-navigation-example/external-navigation-example");
const workflow_glsp_client_contribution_1 = require("./workflow-glsp-client-contribution");
class WorkflowTheiaFrontendModule extends theia_integration_1.GLSPTheiaFrontendModule {
    constructor() {
        super(...arguments);
        this.enableCopyPaste = true;
        this.diagramLanguage = workflow_language_1.WorkflowLanguage;
    }
    bindDiagramConfiguration(context) {
        context.bind(sprotty_theia_1.DiagramConfiguration).to(workflow_diagram_configuration_1.WorkflowDiagramConfiguration);
    }
    configure(context) {
        // Custom workflow commands and menus
        context.bind(core_1.CommandContribution).to(workflow_task_editing_context_menu_1.WorkflowTaskEditCommandContribution);
        context.bind(core_1.MenuContribution).to(workflow_task_editing_context_menu_1.WorkflowTaskEditMenuContribution);
        context.bind(core_1.CommandContribution).to(workflow_navigation_context_menu_1.WorkflowNavigationCommandContribution);
        context.bind(core_1.MenuContribution).to(workflow_navigation_context_menu_1.WorkflowNavigationMenuContribution);
        context.bind(browser_1.KeybindingContext).to(workflow_keybinding_contribution_1.WorkflowDiagramKeybindingContext);
        context.bind(browser_1.KeybindingContribution).to(workflow_keybinding_contribution_1.WorkflowKeybindingContribution);
        // Example for a command that navigates to an element in a diagram with a query resolved by the server
        context.bind(core_1.CommandContribution).to(external_navigation_example_1.ExampleNavigationCommandContribution).inSingletonScope();
        // Readonly workflow diagram view
        context.bind(workflow_diagram_readonly_view_1.WorkflowDiagramReadonlyViewContribution).toSelf().inSingletonScope();
        context.bind(core_1.MenuContribution).toService(workflow_diagram_readonly_view_1.WorkflowDiagramReadonlyViewContribution);
        context.bind(core_1.CommandContribution).toService(workflow_diagram_readonly_view_1.WorkflowDiagramReadonlyViewContribution);
    }
    bindGLSPClientContribution(context) {
        context.bind(theia_integration_1.GLSPClientContribution).to(workflow_glsp_client_contribution_1.WorkflowGLSPClientContribution);
    }
}
exports.WorkflowTheiaFrontendModule = WorkflowTheiaFrontendModule;
exports.default = new WorkflowTheiaFrontendModule();
//# sourceMappingURL=workflow-frontend-module.js.map